@@ -4,8 +4,8 @@
 
 ;; Author: James Ferguson <(concat "wjcferguson" at-sign "gmail.com")>
 ;; URL: https://github.com/WJCFerguson/emacs-faff-theme
-;; Package-Version: 20251120.1400
-;; Package-Revision: e8b6b4b5669f
+;; Package-Version: 20251229.2005
+;; Package-Revision: 234889b84663
 ;; Keywords: color theme
 
 ;; This file is not part of GNU Emacs.
@@ -57,6 +57,7 @@
  '(ansi-color-magenta ((t (:background "magenta4" :foreground "magenta4"))))
  '(ansi-color-slow-blink ((t (:box (1 . -1)))))
  '(ansi-color-yellow ((t (:background "yellow4" :foreground "yellow4"))))
+ '(ansi-color-faint ((t (:foreground "gray50"))))
  '(bookmark-face ((t (:background "cornsilk3" :foreground "DarkOrange1"))))
  '(breakpoint-disabled ((t (:foreground "grey40"))))
  '(eglot-highlight-symbol-face ((t (:background "cornsilk2" :inherit bold))))
@@ -66,7 +67,7 @@
  '(eshell-ls-executable ((t (:foreground "DarkGreen" :weight bold))))
  '(eshell-ls-product ((t (:foreground "OrangeRed4"))))
  '(eshell-ls-special ((t (:foreground "Magenta4" :weight bold))))
- '(eshell-prompt ((t (:background "cornsilk2" :weight bold))))
+ '(eshell-prompt ((t (:background "#ddd8bd"))))
  '(match ((t (:background "yellow2"))))
  '(cursor ((t (:background "red3"))))
  '(variable-pitch ((t (:family "Sans Serif"))))
